@@ -5,6 +5,7 @@
  */
 
 #include "models/trackmetadatamodel.h"
+#include "models/trackmetadataproxymodel.h"
 
 #include "databasetestdata.h"
 
@@ -15,6 +16,8 @@
 #include <QSignalSpy>
 #include <QTest>
 
+constexpr auto trackRowCount = 19;
+
 class TrackMetadataModelTests: public QObject, public DatabaseTestData
 {
     Q_OBJECT
@@ -34,7 +37,10 @@ private Q_SLOTS:
     void loadOneTrackData()
     {
         TrackMetadataModel myModel;
+        TrackMetadataProxyModel proxyModel;
+        proxyModel.setSourceModel(&myModel);
         QAbstractItemModelTester testModel(&myModel);
+        QAbstractItemModelTester testProxyModel(&proxyModel);
 
         QSignalSpy beginResetSpy(&myModel, &TrackMetadataModel::modelAboutToBeReset);
         QSignalSpy endResetSpy(&myModel, &TrackMetadataModel::modelReset);
@@ -52,6 +58,7 @@ private Q_SLOTS:
         QCOMPARE(beginRemovedRowsSpy.count(), 0);
         QCOMPARE(endRemovedRowsSpy.count(), 0);
         QCOMPARE(myModel.rowCount(), 0);
+        QCOMPARE(proxyModel.rowCount(), 0);
 
         auto trackData = TrackMetadataModel::TrackDataType{{DataTypes::DatabaseIdRole, 1},
                                                            {DataTypes::TitleRole, QStringLiteral("title")},
@@ -65,7 +72,11 @@ private Q_SLOTS:
         QCOMPARE(dataChangedSpy.count(), 0);
         QCOMPARE(beginRemovedRowsSpy.count(), 0);
         QCOMPARE(endRemovedRowsSpy.count(), 0);
-        QCOMPARE(myModel.rowCount(), 2);
+        QCOMPARE(myModel.rowCount(), trackRowCount);
+        QCOMPARE(proxyModel.rowCount(), 2);
+
+        proxyModel.setShowTagsWithNoData(true);
+        QCOMPARE(proxyModel.rowCount(), trackRowCount);
     }
 
     void modifyTrackInDatabase()
@@ -82,7 +93,10 @@ private Q_SLOTS:
         musicDb.insertTracksList(mNewTracks, mNewCovers);
 
         TrackMetadataModel myModel;
+        TrackMetadataProxyModel proxyModel;
+        proxyModel.setSourceModel(&myModel);
         QAbstractItemModelTester testModel(&myModel);
+        QAbstractItemModelTester testProxyModel(&proxyModel);
 
         QSignalSpy beginResetSpy(&myModel, &TrackMetadataModel::modelAboutToBeReset);
         QSignalSpy endResetSpy(&myModel, &TrackMetadataModel::modelReset);
@@ -100,6 +114,7 @@ private Q_SLOTS:
         QCOMPARE(beginRemovedRowsSpy.count(), 0);
         QCOMPARE(endRemovedRowsSpy.count(), 0);
         QCOMPARE(myModel.rowCount(), 0);
+        QCOMPARE(proxyModel.rowCount(), 0);
 
         myModel.setDatabase(&musicDb);
 
@@ -114,7 +129,12 @@ private Q_SLOTS:
         QCOMPARE(dataChangedSpy.count(), 0);
         QCOMPARE(beginRemovedRowsSpy.count(), 0);
         QCOMPARE(endRemovedRowsSpy.count(), 0);
-        QCOMPARE(myModel.rowCount(), 12);
+        QCOMPARE(myModel.rowCount(), trackRowCount);
+        QCOMPARE(proxyModel.rowCount(), 12);
+
+        proxyModel.setShowTagsWithNoData(true);
+        QCOMPARE(proxyModel.rowCount(), trackRowCount);
+        proxyModel.setShowTagsWithNoData(false);
 
         musicDb.trackHasStartedPlaying(QUrl::fromLocalFile(QStringLiteral("/$2")), QDateTime::currentDateTime());
 
@@ -125,7 +145,11 @@ private Q_SLOTS:
         QCOMPARE(dataChangedSpy.count(), 0);
         QCOMPARE(beginRemovedRowsSpy.count(), 0);
         QCOMPARE(endRemovedRowsSpy.count(), 0);
-        QCOMPARE(myModel.rowCount(), 12);
+        QCOMPARE(myModel.rowCount(), trackRowCount);
+        QCOMPARE(proxyModel.rowCount(), 12);
+
+        proxyModel.setShowTagsWithNoData(true);
+        QCOMPARE(proxyModel.rowCount(), trackRowCount);
     }
 };
 
